/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */

#ifndef INCLUDED_ORCUS_INFO_HPP

#include "orcus/env.hpp"

namespace orcus {

ORCUS_DLLPUBLIC int get_version_major();
ORCUS_DLLPUBLIC int get_version_minor();
ORCUS_DLLPUBLIC int get_version_micro();

}

#endif

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
